==> hlog-0.18.tar.gz: hlog-0.18/daemon/daemon.c <==
/*
 * Copyright (c) 2020-2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <jeffpc/version.h>
#include <jeffpc/error.h>
#include <jeffpc/io.h>
#include <jeffpc/thread.h>

#include <locale.h>

#include <hlog/country.h>
#include <hlog/version.h>
#include <hlog-rpc/announce.h>
#include <hlog-rpc/announce-pub.h>

#include "index.h"
#include "location.h"
#include "wsjtx.h"

#define DATA_DIR_COUNTRY_FNAME	"cty.csv"

static int load_countries(void)
{
	int ret;

	cmn_err(CE_INFO, "Loading countries data...");
	ret = country_load(AT_FDCWD, DATA_DIR_COUNTRY_FNAME);
	cmn_err(CE_INFO, "%s.", ret ? "error" : "done");

	if (ret)
		cmn_err(CE_ERROR, "Error: failed to load country data: %s",
			xstrerror(ret));

	return ret;
}

static void usage(const char *prog)
{
	fprintf(stderr, "hlogd version %s\n\n", version_string);
	fprintf(stderr, "Usage: %s <path to data dir>\n", prog);
	exit(1);
}

int main(int argc, char **argv)
{
	const char *data_dir;
	int ret;

	setlocale(LC_ALL, "");
	ASSERT0(putenv("TZ=UTC"));

	xthr_set_name("main");

	if (argc != 2)
		usage(argv[0]);

	cmn_err(CE_INFO, "hlogd version %s", version_string);
	cmn_err(CE_INFO, "libjeffpc version %s", jeffpc_version);

	data_dir = argv[1];

	/*
	 * chdir to the data directory to make our lives in the future much
	 * easier.  We will be able to use relative paths everywhere.
	 */
	if (chdir(data_dir)) {
		cmn_err(CE_ERROR, "Error: failed to change to data dir: %s",
			strerror(errno));
		goto err;
	}

	ret = load_countries();
	if (ret)
		goto err;

	ret = index_init();
	if (ret)
		goto err;

	ret = announce_start();
	if (ret)
		goto err;

	ret = location_start();
	if (ret)
		goto err_announce;

	ret = wsjtx_start();
	if (ret)
		goto err_location;

	for (;;)
		sleep(60);

	location_stop();
	announce_stop();

	return 0;

err_location:
	location_stop();

err_announce:
	announce_stop();

err:
	return 1;
}

==> hlog-0.20-rc1.tar.gz: hlog-0.20-rc1/daemon/daemon.c <==
/*
 * Copyright (c) 2020-2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <locale.h>

#include <jeffpc/version.h>
#include <jeffpc/error.h>
#include <jeffpc/io.h>
#include <jeffpc/thread.h>

#include <hlog/country.h>
#include <hlog/version.h>
#include <hlog-rpc/announce.h>
#include <hlog-rpc/announce-pub.h>

#include "index.h"
#include "location.h"
#include "wsjtx.h"

#define DATA_DIR_COUNTRY_FNAME	"cty.csv"

static int load_countries(void)
{
	int ret;

	cmn_err(CE_INFO, "Loading countries data...");
	ret = country_load(AT_FDCWD, DATA_DIR_COUNTRY_FNAME);
	cmn_err(CE_INFO, "%s.", ret ? "error" : "done");

	if (ret)
		cmn_err(CE_ERROR, "Error: failed to load country data: %s",
			xstrerror(ret));

	return ret;
}

static void usage(const char *prog, const char *fmt, ...)
{
	if (fmt) {
		va_list ap;

		fprintf(stderr, "Error: ");

		va_start(ap, fmt);
		vfprintf(stderr, fmt, ap);
		va_end(ap);

		fprintf(stderr, "\n");
	}

#define P(...) fprintf(stderr, __VA_ARGS__)

	P("hlogd version %s\n\n", version_string);
	P("Usage: %s <data dir>\n", prog);
	P("\n");

#undef P

	exit(1);
}

int main(int argc, char **argv)
{
	const char *data_dir;
	int opt;
	int ret;

	setlocale(LC_ALL, "");
	ASSERT0(putenv("TZ=UTC"));

	xthr_set_name("main");

	while ((opt = getopt(argc, argv, "")) != -1) {
		switch (opt) {
			default:
				usage(argv[0], NULL);
				break;
		}
	}

	/* missing data dir path */
	if ((optind + 1) != argc)
		usage(argv[0], "data directory is required");

	data_dir = argv[argc - 1];

	cmn_err(CE_INFO, "hlogd version %s", version_string);
	cmn_err(CE_INFO, "libjeffpc version %s", jeffpc_version);

	/*
	 * chdir to the data directory to make our lives in the future much
	 * easier.  We will be able to use relative paths everywhere.
	 */
	if (chdir(data_dir)) {
		cmn_err(CE_ERROR, "Error: failed to change to data dir: %s",
			strerror(errno));
		goto err;
	}

	ret = load_countries();
	if (ret)
		goto err;

	ret = index_init();
	if (ret)
		goto err;

	ret = announce_start();
	if (ret)
		goto err;

	ret = location_start();
	if (ret)
		goto err_announce;

	ret = wsjtx_start();
	if (ret)
		goto err_location;

	for (;;)
		sleep(60);

	wsjtx_stop();
	location_stop();
	announce_stop();

	return 0;

err_location:
	location_stop();

err_announce:
	announce_stop();

err:
	return 1;
}
